---
title: Install
---


## Install

    pip install hope-smart-import

## Setup

In your `settings.py`:
 
    INSTALLED_APPS = [
        ...
        "hope_flex_fields",
        "hope_smart_import",
    ]
